@@ -140,7 +140,7 @@ class UnicodeData:
         return None
 
 
-# http://www.unicode.org/Public/10.0.0/ucd/DerivedCoreProperties.txt
+# https://www.unicode.org/Public/UNIDATA/DerivedCoreProperties.txt
 # Derived Property: Default_Ignorable_Code_Point
 _DEFAULT_IGNORABLE = CodepointSet('''
 00AD
@@ -150,6 +150,7 @@ _DEFAULT_IGNORABLE = CodepointSet('''
 17B4..17B5
 180B..180D
 180E
+180F
 200B..200F
 202A..202E
 2060..2064
@@ -170,9 +171,9 @@ E0080..E00FF
 E0100..E01EF
 E01F0..E0FFF
 ''')
-assert len(_DEFAULT_IGNORABLE) == 4173
+assert len(_DEFAULT_IGNORABLE) == 4174
 
-# http://www.unicode.org/Public/10.0.0/ucd/extracted/DerivedJoiningType.txt
+# https://www.unicode.org/Public/UNIDATA/extracted/DerivedJoiningType.txt
 # Joining_Type=Dual_Joining
 _JOINTYPE_DUAL_JOINING = CodepointSet('''
 0620
@@ -211,15 +212,16 @@ _JOINTYPE_DUAL_JOINING = CodepointSet('''
 0860
 0862..0865
 0868
+0886
+0889..088D
 08A0..08A9
 08AF..08B0
-08B3..08B4
-08B6..08B8
-08BA..08BD
+08B3..08B8
+08BA..08C8
 1807
 1820..1842
 1843
-1844..1877
+1844..1878
 1887..18A8
 18AA
 A840..A871
@@ -235,11 +237,26 @@ A840..A871
 10B8D
 10B90
 10BAD..10BAE
+10D01..10D21
+10D23
+10F30..10F32
+10F34..10F44
+10F51..10F53
+10F70..10F73
+10F76..10F81
+10FB0
+10FB2..10FB3
+10FB8
+10FBB..10FBC
+10FBE..10FBF
+10FC1
+10FC4
+10FCA
 1E900..1E943
 ''')
-assert len(_JOINTYPE_DUAL_JOINING) == 507
+assert len(_JOINTYPE_DUAL_JOINING) == 610
 
-# http://www.unicode.org/Public/10.0.0/ucd/extracted/DerivedJoiningType.txt
+# https://www.unicode.org/Public/UNIDATA/extracted/DerivedJoiningType.txt
 # Joining_Type=Right_Joining
 _JOINTYPE_RIGHT_JOINING = CodepointSet('''
 0622..0625
@@ -274,8 +291,11 @@ _JOINTYPE_RIGHT_JOINING = CodepointSet('''
 0846..0847
 0849
 0854
+0856..0858
 0867
 0869..086A
+0870..0882
+088E
 08AA..08AC
 08AE
 08B1..08B2
@@ -295,19 +315,30 @@ _JOINTYPE_RIGHT_JOINING = CodepointSet('''
 10B8E..10B8F
 10B91
 10BA9..10BAC
+10D22
+10F33
+10F54
+10F74..10F75
+10FB4..10FB6
+10FB9..10FBA
+10FBD
+10FC2..10FC3
+10FC9
 ''')
-assert len(_JOINTYPE_RIGHT_JOINING) == 115
+assert len(_JOINTYPE_RIGHT_JOINING) == 152
 
-# http://www.unicode.org/Public/10.0.0/ucd/extracted/DerivedJoiningType.txt
+# https://www.unicode.org/Public/UNIDATA/extracted/DerivedJoiningType.txt
 # Joining_Type=Left_Joining
 _JOINTYPE_LEFT_JOINING = CodepointSet('''
 A872
 10ACD
 10AD7
+10D00
+10FCB
 ''')
-assert len(_JOINTYPE_LEFT_JOINING) == 3
+assert len(_JOINTYPE_LEFT_JOINING) == 5
 
-# http://www.unicode.org/Public/10.0.0/ucd/extracted/DerivedJoiningType.txt
+# https://www.unicode.org/Public/UNIDATA/extracted/DerivedJoiningType.txt
 # Joining_Type=Transparent
 _JOINTYPE_TRANSPARENT = CodepointSet('''
 00AD
@@ -332,12 +363,14 @@ _JOINTYPE_TRANSPARENT = CodepointSet('''
 0730..074A
 07A6..07B0
 07EB..07F3
+07FD
 0816..0819
 081B..0823
 0825..0827
 0829..082D
 0859..085B
-08D4..08E1
+0898..089F
+08CA..08E1
 08E3..0902
 093A
 093C
@@ -350,6 +383,7 @@ _JOINTYPE_TRANSPARENT = CodepointSet('''
 09C1..09C4
 09CD
 09E2..09E3
+09FE
 0A01..0A02
 0A3C
 0A41..0A42
@@ -370,12 +404,14 @@ _JOINTYPE_TRANSPARENT = CodepointSet('''
 0B3F
 0B41..0B44
 0B4D
-0B56
+0B55..0B56
 0B62..0B63
 0B82
 0BC0
 0BCD
 0C00
+0C04
+0C3C
 0C3E..0C40
 0C46..0C48
 0C4A..0C4D
@@ -392,6 +428,7 @@ _JOINTYPE_TRANSPARENT = CodepointSet('''
 0D41..0D44
 0D4D
 0D62..0D63
+0D81
 0DCA
 0DD2..0DD4
 0DD6
@@ -399,9 +436,8 @@ _JOINTYPE_TRANSPARENT = CodepointSet('''
 0E34..0E3A
 0E47..0E4E
 0EB1
-0EB4..0EB9
-0EBB..0EBC
-0EC8..0ECD
+0EB4..0EBC
+0EC8..0ECE
 0F18..0F19
 0F35
 0F37
@@ -425,7 +461,7 @@ _JOINTYPE_TRANSPARENT = CodepointSet('''
 109D
 135D..135F
 1712..1714
-1732..1734
+1732..1733
 1752..1753
 1772..1773
 17B4..17B5
@@ -434,6 +470,7 @@ _JOINTYPE_TRANSPARENT = CodepointSet('''
 17C9..17D3
 17DD
 180B..180D
+180F
 1885..1886
 18A9
 1920..1922
@@ -451,6 +488,7 @@ _JOINTYPE_TRANSPARENT = CodepointSet('''
 1A7F
 1AB0..1ABD
 1ABE
+1ABF..1ACE
 1B00..1B03
 1B34
 1B36..1B3A
@@ -473,8 +511,7 @@ _JOINTYPE_TRANSPARENT = CodepointSet('''
 1CED
 1CF4
 1CF8..1CF9
-1DC0..1DF9
-1DFB..1DFF
+1DC0..1DFF
 200B
 200E..200F
 202A..202E
@@ -499,14 +536,16 @@ A802
 A806
 A80B
 A825..A826
+A82C
 A8C4..A8C5
 A8E0..A8F1
+A8FF
 A926..A92D
 A947..A951
 A980..A982
 A9B3
 A9B6..A9B9
-A9BC
+A9BC..A9BD
 A9E5
 AA29..AA2E
 AA31..AA32
@@ -538,33 +577,43 @@ FFF9..FFFB
 10A38..10A3A
 10A3F
 10AE5..10AE6
+10D24..10D27
+10EAB..10EAC
+10EFD..10EFF
+10F46..10F50
+10F82..10F85
 11001
 11038..11046
+11070
+11073..11074
 1107F..11081
 110B3..110B6
 110B9..110BA
-110BD
+110C2
 11100..11102
 11127..1112B
 1112D..11134
 11173
 11180..11181
 111B6..111BE
-111CA..111CC
+111C9..111CC
+111CF
 1122F..11231
 11234
 11236..11237
 1123E
+11241
 112DF
 112E3..112EA
 11300..11301
-1133C
+1133B..1133C
 11340
 11366..1136C
 11370..11374
 11438..1143F
 11442..11444
 11446
+1145E
 114B3..114B8
 114BA
 114BF..114C0
@@ -583,8 +632,15 @@ FFF9..FFFB
 1171D..1171F
 11722..11725
 11727..1172B
-11A01..11A06
-11A09..11A0A
+1182F..11837
+11839..1183A
+1193B..1193C
+1193E
+11943
+119D4..119D7
+119DA..119DB
+119E0
+11A01..11A0A
 11A33..11A38
 11A3B..11A3E
 11A47
@@ -604,11 +660,26 @@ FFF9..FFFB
 11D3C..11D3D
 11D3F..11D45
 11D47
+11D90..11D91
+11D95
+11D97
+11EF3..11EF4
+11F00..11F01
+11F36..11F3A
+11F40
+11F42
+13430..1343F
+13440
+13447..13455
 16AF0..16AF4
 16B30..16B36
+16F4F
 16F8F..16F92
+16FE4
 1BC9D..1BC9E
 1BCA0..1BCA3
+1CF00..1CF2D
+1CF30..1CF46
 1D167..1D169
 1D173..1D17A
 1D17B..1D182
@@ -626,15 +697,21 @@ FFF9..FFFB
 1E01B..1E021
 1E023..1E024
 1E026..1E02A
+1E08F
+1E130..1E136
+1E2AE
+1E2EC..1E2EF
+1E4EC..1E4EF
 1E8D0..1E8D6
 1E944..1E94A
+1E94B
 E0001
 E0020..E007F
 E0100..E01EF
 ''')
-assert len(_JOINTYPE_TRANSPARENT) == 1912
+assert len(_JOINTYPE_TRANSPARENT) == 2150
 
-# http://www.unicode.org/Public/10.0.0/ucd/Scripts.txt
+# https://www.unicode.org/Public/UNIDATA/Scripts.txt
 # Greek
 _GREEK_SCRIPT = CodepointSet('''
 0370..0373
@@ -695,7 +772,7 @@ AB65
 ''')
 assert len(_GREEK_SCRIPT) == 518
 
-# http://www.unicode.org/Public/10.0.0/ucd/Scripts.txt
+# https://www.unicode.org/Public/UNIDATA/Scripts.txt
 # Hebrew
 _HEBREW_SCRIPT = CodepointSet('''
 0591..05BD
@@ -708,7 +785,7 @@ _HEBREW_SCRIPT = CodepointSet('''
 05C6
 05C7
 05D0..05EA
-05F0..05F2
+05EF..05F2
 05F3..05F4
 FB1D
 FB1E
@@ -721,18 +798,20 @@ FB40..FB41
 FB43..FB44
 FB46..FB4F
 ''')
-assert len(_HEBREW_SCRIPT) == 133
+assert len(_HEBREW_SCRIPT) == 134
 
-# http://www.unicode.org/Public/10.0.0/ucd/Scripts.txt
+# https://www.unicode.org/Public/UNIDATA/Scripts.txt
 # Hiragana, Katakana, Han
 _HIRAGANA_KATAKANA_HAN = CodepointSet('''
-# Hiragana (376)
+# Hiragana (381)
 3041..3096
 309D..309E
 309F
-1B001..1B11E
+1B001..1B11F
+1B132
+1B150..1B152
 1F200
-# Katakana (300)
+# Katakana (321)
 30A1..30FA
 30FD..30FE
 30FF
@@ -741,8 +820,14 @@ _HIRAGANA_KATAKANA_HAN = CodepointSet('''
 3300..3357
 FF66..FF6F
 FF71..FF9D
+1AFF0..1AFF3
+1AFF5..1AFFB
+1AFFD..1AFFE
 1B000
-# Han (89228)
+1B120..1B122
+1B155
+1B164..1B167
+# Han (98408)
 2E80..2E99
 2E9B..2EF3
 2F00..2FD5
@@ -751,20 +836,25 @@ FF71..FF9D
 3021..3029
 3038..303A
 303B
-3400..4DB5
-4E00..9FEA
+3400..4DBF
+4E00..9FFF
 F900..FA6D
 FA70..FAD9
-20000..2A6D6
-2A700..2B734
+16FE2
+16FE3
+16FF0..16FF1
+20000..2A6DF
+2A700..2B739
 2B740..2B81D
 2B820..2CEA1
 2CEB0..2EBE0
 2F800..2FA1D
+30000..3134A
+31350..323AF
 ''')
-assert len(_HIRAGANA_KATAKANA_HAN) == (376 + 300 + 89228)
+assert len(_HIRAGANA_KATAKANA_HAN) == (381 + 321 + 98408)
 
-# http://www.unicode.org/Public/10.0.0/ucd/HangulSyllableType.txt
+# https://www.unicode.org/Public/UNIDATA/HangulSyllableType.txt
 # Leading_Jamo, Vowel_Jamo, Trailing_Jamo
 _OLD_HANGUL_JAMO = CodepointSet('''
 # Leading_Jamo (125)
